<?php

namespace App\Http\Controllers\Api\V1;


use App\Models\AlbumAgentModel;
use App\Models\AlbumBannerModel;
use App\Models\AlbumCatModel;
use App\Models\AlbumCommentsModel;
use App\Models\AlbumFavoriteModel;
use App\Models\AlbumFormId;
use App\Models\AlbumInformationModel;
use App\Models\AlbumManufacturerModel;
use App\Models\AlbumNavModel;
use App\Models\AlbumNewsModel;
use App\Models\AlbumProductModel;
use App\Models\AlbumProductPriceModel;
use App\Models\AlbumProductStyleModel;
use App\Models\AlbumUserModel;
use App\Models\AlbumWatchRecord;
use App\Models\AlbumXyxUserModel;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Validator, Response,Auth;
use App\Services\Base\ErrorCode;
use WXBizDataCrypt;
use EasyWeChat\Factory;

class AlbumController extends Controller
{

    private $wechat_app;


    public function albumSetting(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ], [
            'store_id.required' => '店铺信息未知',
        ]);
        if ($validator->fails()) {
            return $this->validatorError($validator->messages()->all(), ErrorCode::CLIENT_WRONG_PARAMS, '');
        }
        $store_id = $request->store_id;
        //小程序設置

        $setting = AlbumManufacturerModel::where('store_id',$store_id)->first();
        //轮播图
        $banner = AlbumBannerModel::where('store_id',$store_id)->orderByDesc('sort')->get();

        //底部导航栏
        $navbar = AlbumNavModel::where([['store_id',$store_id],['state',0]])->orderByDesc('sort')->get();

        //顶部菜单栏
        $menus = AlbumNavModel::where([['store_id',$store_id],['state',1]])->orderByDesc('sort')->get();

        $news = AlbumNewsModel::where([['store_id',$store_id]])->orderByDesc('sort')->paginate(5);

        return $this->api(compact('setting','banner','news','navbar','menus'));
    }

    /**
     * @api {post} /api/album/login 登陆(login)
     * @apiDescription 登陆(login)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {string}     code              小程序登录生成的code
     * @apiParam {string}     nickName          微信昵称
     * @apiParam {string}     avatar            微信头像
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *
     *      }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumXcxLogin(Request $request)
    {
        $validator = Validator::make($request->all(),
            [
                'code' => 'required',
                'store_id' => 'required'
               /* 'nickName' => 'required',
                'avatar' => 'required',*/
            ],
            [
                'code.required' => 'code不能为空!',
                'store_id.required' => 'store_id不能为空!'
                /*'nickName.required' => 'nickName不能为空!',
                'avatar.required' => 'avatar不能为空!',*/
            ]
        );


        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }

        $storeid = $request->get('store_id');

        $this->wechat_app = AlbumManufacturerModel::where('store_id',$storeid)->first();
        $config = [
            'app_id' => $this->wechat_app->app_id,
            'secret' => $this->wechat_app->app_secret,

            // 下面为可选项
            // 指定 API 调用返回结果的类型：array(default)/collection/object/raw/自定义类名
            'response_type' => 'array',
        ];
        $app = Factory::miniProgram($config);


        $code = $request->get('code');
        $session = $app->auth->session($code);
        \Log::info(json_encode($session));
        $openid = $session['openid'];


        $userinfo = AlbumUserModel::where('wechat_open_id', $openid)->where('store_id',$storeid)->first(['id', 'username','wechat_open_id','avatar']);

        if (!$userinfo) {
            $data['wechat_open_id'] = $openid;
            $data['username'] = $request->get('nickName');
            $data['avatar'] = $request->get('avatar');
            $data['is_dealer'] = 0;

            $userinfo = AlbumUserModel::create($data);
        }

        if (Auth::loginUsingId($userinfo->id)) {
            $user = Auth::user();
            $token = $user->createToken($user->id . '-' . $user->openid)->accessToken;
            return $this->api(compact('token', 'user', 'session_key'));
        } else {

            return $this->error(ErrorCode::INCORRECT_USER_OR_PASS);
        }
    }

    /**
     * @api {post} /api/album/xyx_login 登陆(xyx_login)
     * @apiDescription 登陆(xyx_login)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [code]
     * @apiParam {int}    [agent_id]  经销商id
     * @apiParam {int}    [store_id]  商户id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *           "token": "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiIsImp0aSI6ImIyNGI3MzY3MDNmZDg3MGFjNTg2MWIxNDUzMDcyYjljYzFmNmJhMzE2NTAxZWVlNGYzM2M5MTIzNzFmNGYzZjg2MTY1M2YxMjE2YzE4OTFiIn0.eyJhdWQiOiI5IiwianRpIjoiYjI0YjczNjcwM2ZkODcwYWM1ODYxYjE0NTMwNzJiOWNjMWY2YmEzMTY1MDFlZWU0ZjMzYzkxMjM3MWY0ZjNmODYxNjUzZjEyMTZjMTg5MWIiLCJpYXQiOjE1NDA3OTYyMTYsIm5iZiI6MTU0MDc5NjIxNiwiZXhwIjoxNTcyMzMyMjE1LCJzdWIiOiIxIiwic2NvcGVzIjpbXX0.Ruihvl_HMCAHx9XDfeckz48Q_72kfG7vWDsqDrZWbrjq-yuNpM3LrUF-nlsKjedo97BwU_Apz-jnGVqr0ONKZlH-aBKDmIgM2aUZfFADsHhHNJH_oU2fMe1bOrjfUp-PJxfVWQS8c8h5RYmeqtzAYCKaD4P7OZbLmOX0YosKghpaGtiyE65s6jtrOXRhAzXAhYsZToQNBMokFVRqGih9EWuVp6EVwRtI3cb4IV6iQf08cX9DGlLLBJJzLWR5ZWgxJLAGrj5iMCWBl4JKVR8Fsy-xnx3EtrB7ODpJH6hB_u3XnUSAFuaG-KzMPLsj45iqg2hy53er2xtcfAowQFsPoAbZZu0n8c9hWt4GLemR6N1iZ3LBViv3tL5BK52pinQzAnmvltAhJP1YhfTOOjzkxcYVh2JeJagufEoxeeUarMMn21gQSFEzKFCimI7zZQxhT9leLpUn51DLD8Mu87NpYb3JN-JFbOlIDA7bDN3bNto7uuSuC4eBwPo3Ge0StuW4kjHsDTcrVF2He_8FdrPcPpGcvQsXQgv4vwlEhbL8dTlrOodum7H_tY_qUxUG1pEg6bfpn_82ej-AOSc9xi0nrhdcS9y_Z68rcwOJu8esI1pXm9TeQdZIDG85y_t74At8XN6oFcIM__6_dTne_3DHwijW-uOLupNky-5J4ILmZck",
     *           "user": {
     *               "user_id": 1,
     *               "is_agent": 1,
     *               "agent_id": 4
     *            }
     *      }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumXyxLogin(Request $request)
    {
        $datas = $request->input();
        $validator = Validator::make($request->all(),
            [
                'code' => 'required',
                'agent_id' => 'required',
                'nickName' => 'required',
                'avatar' => 'required',
                'store_id' => 'required'
            ],[
                'code.required' => 'code不能为空!',
                'agent_id.required' => 'agent_id不能为空!',
                'nickName.required' => '昵称不能为空!',
                'avatar.required' => '头像不能为空!',
                'store_id.required' => '站点ID不能为空!'
            ]
        );
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $this->wechat_app = AlbumManufacturerModel::where('store_id',$datas['store_id'])->first();
        if(!$this->wechat_app) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        $config = [
            'app_id' => $this->wechat_app->xyx_id,
            'secret' => $this->wechat_app->xyx_secret,

            // 下面为可选项
            // 指定 API 调用返回结果的类型：array(default)/collection/object/raw/自定义类名
            'response_type' => 'array',


        ];

        $app = Factory::miniProgram($config);
        $res = $app->auth->session($datas['code']);
       // dd($res);
        if (!$res || empty($res['openid'])) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '获取用户OpenId失败!', $validator->messages());
        }

        $session_key = $res['session_key'];


            $check = AlbumUserModel::where('wechat_open_id',$res['openid'])->first();
            if(!$check){
                $add['username'] = preg_replace('/[\xf0-\xf7].{3}/', '', $datas['nickName']);
                $add['wechat_open_id'] = $res['openid'];
                $add['wechat_union_id'] = '';
                $add['avatar'] = $datas['avatar'];
                $add['is_agent'] = 0;
                $add['store_id'] = $datas['store_id'];
                $res = AlbumUserModel::create($add);
                if($res){
                    $check = AlbumUserModel::where([['wechat_open_id',$res['openid']],['store_id',$datas['store_id']]])->first();
                    $user = [
                        'user_id'=>$check['id'],
                        //'avatar'=>$check['avatar'],
                       // 'username'=>$check['username'],
                        'phone'=>$check->phone,
                        'is_agent'=>0,
                        'agent_id'=>'',
                    ];
                }else{
                    $user=[
                        'error'=>1
                    ];
                }
            } else {
                //print_r($check);die;
                $save['username'] = preg_replace('/[\xf0-\xf7].{3}/', '', $datas['nickName']);
                $save['avatar'] = $datas['avatar'];
                $res = AlbumUserModel::where('wechat_open_id',$res['openid'])->update($save);
                //echo 111;
                    //print_r($check);die;
                    if($check->is_dealer == 1){
                        $user_agent = AlbumAgentModel::where('user_id',$check->id)->first();
                        $agent_id = $user_agent['id'];
                    } else {
                        $agent_id = '';
                    }
                    $user = [

                        'user_id'=>$check->id,
                        'phone'=>$check->phone,
                        //'avatar'=>$datas['avatar'],
                        //'username'=>$datas['nickName'],
                        'is_agent'=>$check->is_dealer,
                        'agent_id'=>$agent_id,

                    ];

            }
        if (Auth::loginUsingId($check->id)) {
            $userAuth = Auth::user();
            if($check->is_dealer ==0 && $request->input('agent_id')!=0){
                $userAuth->up_agent_id = $request->input('agent_id');
                $add_record['agent_id'] = $request->input('agent_id');
                $add_record['open_id'] = $check->wechat_open_id;
                $add_record['action'] = 4;
                $add_record['store_id'] = $datas['store_id'];
                $add_record['detail'] = null;
                AlbumWatchRecord::create($add_record);
                $user_agent = AlbumAgentModel::where('id',$add_record['agent_id'])->first();
                $agent = AlbumUserModel::where('id',$user_agent->user_id)->first();
                try{
                    $this->sendLogsMessage($datas['store_id'],$agent->wechat_open_id,4,$userAuth->username);
                }catch (\Exception $e){

                }
            }else{
                $userAuth->up_agent_id = 0;
            }
            $userAuth->save();
            $token = $userAuth->createToken($userAuth->id . '-' . $userAuth->openid)->accessToken;
            return $this->api(compact('token', 'user'));
        } else {
            return $this->error(ErrorCode::INCORRECT_USER_OR_PASS);
        }
    }


    /*
    * curl get请求
    */
    public function curl_get($url)
    {
        //初始化
        $ch = curl_init();
        //设置选项，包括URL
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        $output = curl_exec($ch);
        curl_close($ch);

        return $output;
    }

    private function getOpenid($code)
    {
        $api = "https://api.weixin.qq.com/sns/jscode2session?appid={$this->wechat_app->app_id}&secret={$this->wechat_app->app_secret}&js_code={$code}&grant_type=authorization_code";
        $res = $this->curl_get($api);
        $res = json_decode($res, true);
        return $res;
    }

    private function getOpenidxyx($code)
    {
        //$api = "https://api.weixin.qq.com/sns/jscode2session?appid={$this->wechat_app->xyx_id}&secret={$this->wechat_app->xyx_secret}&js_code={$code}&grant_type=authorization_code";
        $api = "https://api.weixin.qq.com/sns/jscode2session?appid={$this->wechat_app->xyx_id}&secret={$this->wechat_app->xyx_secret}&js_code={$code}&grant_type=authorization_code";
        $res = $this->curl_get($api);
        $res = json_decode($res, true);
        return $res;
    }
    /**
     * @api {get} /api/album/goods 商品列表(goods)
     * @apiDescription 商品列表(goods)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [cat_id]  分类id
     * @apiParam {string}    [keywords]  关键词.
     * @apiParam {int}    [status]  状态  1 只选择热销 2 只选择最新上市 3只选择一个风格 4 同时选择热销和最新上市 5同时选择热销和风格 6同时选择最新上市和风格 7全选 0全不选
     * @apiParam {int}    [style]  风格
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *         "goods": [
     *              {
     *                  "id": 3,
     *                  "cover_pic": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *                  "name": "简约",
     *                  "style": "纯白",
     *                  "hot_cake": 1,
     *                  "news": 1,
     *                  "price": ""
     *              }
     *          ],
     *         "name": 品牌名
     *     }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumGoods(Request $request)
    {
        $userAuth = Auth('api')->user();
        $validator = Validator::make($request->all(), [
            'cat_id' => 'required',
            'store_id' => 'required',
            'status' => 'required',
        ],[
            'cat_id.required'=>'缺少分类参数',
            'store_id.required'=>'缺少商户参数',
            'status.required'=>'缺少状态参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        //dd($data);
        $cat_id = request('cat_id');
        $store_id = request('store_id');
        $status = request('status');
        $style = request('style');

        $select_info = ['cat_id'=>$cat_id,'style'=>$style];
        if($userAuth->up_agent_id!=0&&$cat_id!="undefined"&&$style!="undefined"){
            $add_record['agent_id'] = $userAuth->up_agent_id;
            $add_record['open_id'] = $userAuth->wechat_open_id;
            $add_record['action'] = 2;
            $add_record['store_id'] = $store_id;
            $add_record['detail'] = json_encode($select_info);
            AlbumWatchRecord::create($add_record);
            $user_agent = AlbumAgentModel::where('id',$userAuth->up_agent_id)->first();
            $agent = AlbumUserModel::where('id',$user_agent->user_id)->first();
            try{
                $this->sendLogsMessage($store_id,$agent->wechat_open_id,2,$userAuth->username);
            }catch (\Exception $e){

            }
        }
        if(isset($data['keywords'])&&!empty($data['keywords'])) {
            $keywords = '%'.$data['keywords'].'%';
            $goods = AlbumProductModel::where([['name','like',$keywords],['store_id',$data['store_id']]]);
        } else {
            $goods = AlbumProductModel::where([['cat_id',$cat_id],['store_id',$store_id]]);
        }
        if($status == 1) {
            $goods->where([['hot_cake', 1]]);
        }
        if($status == 2){
            $goods->where('news',1);
        }
        if($status == 3){
            $goods->where('style',$style);
        }


        $goods = $goods->select('id','cover_pic','name','style','hot_cake','news')->orderByDesc('sort')->get();

        foreach($goods as $key =>$val){
            if($userAuth->is_dealer != 1){
                if($userAuth->up_agent_id==0){
                    $goods[$key]['price'] = '';
                }else{
                    $check = AlbumProductPriceModel::where([['agent_id',$userAuth->up_agent_id],['store_id',$data['store_id']],['product_id',$val['id']]])->first();
                    if($check){
                        $goods[$key]['price'] = $check->price;
                    }else{
                        $goods[$key]['price'] = '';
                    }
                }
            }elseif($userAuth->is_dealer == 1){
                $user_agent = AlbumAgentModel::where('user_id',$userAuth->id)->first();
                $agent_id = $user_agent['id'];
                $check = AlbumProductPriceModel::where([['agent_id',$agent_id],['store_id',$data['store_id']],['product_id',$val['id']]])->first();
                if($check){
                    $goods[$key]['price'] = $check->price;
                }else{
                    $goods[$key]['price'] = '';
                }
            }
        }
        $data =AlbumManufacturerModel::where('store_id',$store_id)->first();
        $name = $data['name'];
        return $this->api(compact('goods','name'));
    }



    /**
     * @api {get} /api/album/goods-detail 商品详细(goods-detail)
     * @apiDescription 商品列表(goods-detail)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [goods_id]  商品id
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *          "id": 3,
     *          "store_id": 0,
     *          "cat_id": 9,
     *          "specifications_img": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *          "style": "纯白",
     *          "sort": 11,
     *          "cover_pic": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *          "hot_cake": 1,
     *          "news": 1,
     *          "detail": "<p>达达娃达娃达娃大青蛙大全大是大非如果v率v恶策但是许多女性的项目部的不行么法可没副本副本副本么方便</p>",
     *          "created_at": "2018-05-19 15:09:04",
     *          "updated_at": "2018-05-19 15:09:04",
     *          "deleted_at": null,
     *          "install_img": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *          "name": "简约",
     *          "detail_pic": ""
     *          "price": "",
     *          "mobile": "",
     *          "address": "",
     *          "realname": "",
     *          "is_favorite": 1,
     *          "favorite_id": 4
     *      }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumGoodsDetail(Request $request)
    {
      //  $userAuth = AlbumXyxUserModel::find(1);
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'goods_id' => 'required',
            'store_id' => 'required',
        ],[
            'goods_id.required'=>'缺少商品参数',
            'store_id_id.required'=>'缺少STORE参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $goods_id = request('goods_id');
        $store_id = request('store_id');
        $select_info = ['goods_id'=>$goods_id];
        if($userAuth->up_agent_id!=0){
            $add_record['agent_id'] = $userAuth->up_agent_id;
            $add_record['open_id'] = $userAuth->wechat_open_id;
            $add_record['action'] = 3;
            $add_record['store_id'] = $store_id;
            $add_record['detail'] = json_encode($select_info);
            AlbumWatchRecord::create($add_record);
            $user_agent = AlbumAgentModel::where('id',$userAuth->up_agent_id)->first();
            $agent = AlbumUserModel::where('id',$user_agent->user_id)->first();
            try{
                $this->sendLogsMessage($store_id,$agent->wechat_open_id,3,$userAuth->username);
            }catch (\Exception $e){

            }
        }
        $goods = AlbumProductModel::where([['id',$goods_id],['store_id',$store_id]])->first();
        if(!empty($goods) && $userAuth->is_dealer != 1){
            $price = DB::table('album_product_price')->where([['agent_id',$userAuth->up_agent_id],['store_id',$store_id],['product_id',$goods['id']]])->first();
            if(!empty($price)){
                $goods->price = $price->price;
                $goods->mobile = $price->mobile;
                $address = AlbumAgentModel::where('id',$userAuth->up_agent_id)->first();
                $goods->address = $address;
            }else{
                $goods->price = '';
                $goods->mobile = '';
                $goods->address = '';
            }
            $check_favorite = AlbumFavoriteModel::where([['user_id',$userAuth->id],['store_id',$store_id],['product_id',$goods['id']]])->first();
            //dd($check_favorite);
            if($check_favorite){
                $goods->is_favorite = 1;
                $goods->favorite_id = $check_favorite->id;
            }else{
                $goods->is_favorite = 0;
                $goods->favorite_id = '';
            }
        }elseif(!empty($goods) && $userAuth->is_dealer == 1){
            $user_agent = AlbumAgentModel::where('user_id',$userAuth->id)->first();
            $agent_id = $user_agent['id'];
            $price = DB::table('album_product_price')->where([['agent_id',$agent_id],['store_id',$store_id],['product_id',$goods['id']]])->first();
            if(!empty($price)){
                $goods->price = $price->price;
                $goods->mobile = $price->mobile;
                $address = AlbumAgentModel::where('id',$agent_id)->first();
                $goods->address = $address->address;
                $goods->realname = $address->realname;
            }else{
                $goods->price = '';
                $goods->mobile = '';
                $goods->address = '';
            }
            $goods->is_favorite = 0;
            $goods->favorite_id = '';
        }

        return $this->api($goods);
    }

    /**
     * @api {get} /api/album/favorite_list 收藏列表(favorite_list)
     * @apiDescription 收藏列表(favorite_list)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *          {
     *              "id": 4,
     *              "user_id": 1,
     *              "deleted_at": null,
     *              "created_at": "2018-10-29 15:51:47",
     *              "updated_at": "2018-10-29 15:53:15",
     *              "product_id": 3,
     *              "store_id": 0,
     *              "goods": {
     *                  "id": 3,
     *                  "store_id": 0,
     *                  "cat_id": 9,
     *                  "specifications_img": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *                  "style": "纯白",
     *                  "sort": 11,
     *                  "cover_pic": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *                  "hot_cake": 1,
     *                  "news": 1,
     *                  "detail": "<p>达达娃达娃达娃大青蛙大全大是大非如果v率v恶策但是许多女性的项目部的不行么法可没副本副本副本么方便</p>",
     *                  "created_at": "2018-05-19 15:09:04",
     *                  "updated_at": "2018-05-19 15:09:04",
     *                  "deleted_at": null,
     *                  "install_img": "http://admin.xcx.com/upload/images/20180519/02f2dbe0e1046d7cea8b3b52d5642fb8.jpg",
     *                  "name": "简约",
     *                  "detail_pic": ""
     *              }
     *          }
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumFavoriteList(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $favorite = AlbumFavoriteModel::where([['user_id',$userAuth->id],['store_id',$data['store_id']]])->get();
        foreach ($favorite as $key=>$val) {
            $favorite[$key]['goods'] = AlbumProductModel::where([['id',$val['product_id']],['store_id',$data['store_id']]])->first();
        }
        return $this->api($favorite);
    }

    /**
     * @api {post} /api/album/get-watch-recored 查看客户浏览情况(get-watch-recored)
     * @apiDescription 查看客户浏览情况(get-watch-recored)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [type]  查询方式 1 按用户 2 按时间 3 按类型
     * @apiParam {int}    [user_id]  user_id
     * @apiParam {int}    [action]  行为类型 1 收藏  2查看类目 3查看商品 4登陆 5点击图片 6 点击导航 7一键拨号
     * @apiParam {int}    [start_time]  查询开始时间
     * @apiParam {int}    [end_time]  查询结束时间
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *        "type1":{   1 收藏  2查看类目 3查看商品 4登陆 5点击图片 6 点击导航 7一键拨号
     *              "time": 2018-1-1 10:10:12,
     *              "action": '做了什么什么都做',
     *              "user": [
     *                  "username":"王小贱",
     *                  "avatar":"awdawdawdawdawdawd",头像
     *                  "phone":"1123123123123"
     *              ]
     *          }
     *          ...
     *          "count":6;
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumGetWatchRecord(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'type'=>'required'
        ],[
            'store_id.required'=>'缺少商户参数',
            'type.required'=>'缺少类型参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $type = $request->input('type');
        $store_id = $request->input('store_id');
        if($userAuth->is_dealer!=1) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '该用户不是经销商!', $validator->messages());
        $user_agent = AlbumAgentModel::where('user_id',$userAuth->id)->first();
        $query = AlbumWatchRecord::where([['agent_id',$user_agent->id],['store_id',$store_id]]);
        switch ($type){
            case '1':
                if(!$request->input('user_id')) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!');
                $user = AlbumUserModel::find(request('user_id'));
                $query = $query->where('open_id',$user->wechat_open_id);
                break;
            case '2':
                if(!$request->input('start_time')||!$request->input('end_time')) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!');
                $start_time = date('Y-m-d H:i:s',$request->input('start_time'));
                $end_time = date('Y-m-d H:i:s',$request->input('end_time'));//dd($start_time.';'.$end_time);
                $query = $query->where([['created_at','>=',$start_time],['created_at','<=',$end_time]]);

                break;
            case '3':
                if(!$request->input('action')) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!');
                $query = $query->where([['action',$request->input('action')]]);
                break;
        }
        $res = $query->get();
        $action = '';

        foreach($res as $key=>$val){
            \Log::info('action:'.$val->action.',id:'.$val->id.';end');
            if($val->action==4){
                $action = '进入我的画册';
            }elseif($val->action == 1||$val->action ==3){
                $goods_data = json_decode($val->detail,true);
                $goods_id = $goods_data['goods_id'];
                $goods = AlbumProductModel::find($goods_id);
                $cat = AlbumCatModel::find($goods->cat_id);
                $style = AlbumProductStyleModel::find($goods->style);
                $val->action == 1? $act = '收藏':$act = '查看';
                $action = $act.'了您的'.$cat->name.'分类下的'.$style->name.'风格的商品 '.$goods->name;
            }elseif($val->action == 2){

                $cat_data = json_decode($val->detail,true);
                if($cat_data['cat_id']=="undefined"||$cat_data['style']=="undefined"||!$cat_data['style']||!$cat_data['cat_id']) continue;
                $cat = AlbumCatModel::find($cat_data['cat_id']);
                $style = AlbumProductStyleModel::find($cat_data['style']);
                $action = '浏览了您的 '.$cat->name.'分类下的 '.$style->name.'风格的商品列表';
            }elseif($val->action==5){
                $goods_data = json_decode($val->detail,true);
                $goods_id = $goods_data['goods_id'];
                $goods = AlbumProductModel::find($goods_id);
                $cat = AlbumCatModel::find($goods->cat_id);
                $style = AlbumProductStyleModel::find($goods->style);
                $action = '点击了您的'.$cat->name.'分类下的'.$style->name.'风格的商品 '.$goods->name.'的'.$goods_data['detail'];
            }elseif($val->action==6){
                $detail = json_decode($val->detail,true);
                $address = $detail['detail'];
                $action = '查看了您的地址'.$address.'，并且点击了导航';
            }elseif($val->action==7){
                $detail = json_decode($val->detail,true);
                $phone = $detail['detail'];
                $action = '查看了您的电话'.$phone.'，并且点击了拨号';
            }

            $user = AlbumUserModel::where([['wechat_open_id',$val->open_id],['store_id',$val->store_id]])->select(['username','avatar','phone'])->first();
           // dd(111);
            $data_res[] = [
                'time'=>$val->created_at,
                'action'=>$action,
                'user'=>$user
            ];
        }
        return $this->api(compact('data_res'));
    }

    /**
     * @api {post} /api/album/get-cart-of-watch 客户浏览情况概览(get-cart-of-watch)
     * @apiDescription 客户浏览情况概览(get-cart-of-watch)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *         "user": {
     *              "username":"王小贱",
     *              "avatar":"awdawdawdawdawdawd",头像
     *               "phone":"1123123123123"
     *              }
     *         "count":6,
     *         "action":[
     *              "type1":1,
     *              "type2":1,
     *              "type3":1,
     *              "type4":1,
     *              "type5":1,
     *              "type6":1,
     *              "type7":1,
     *          ]
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumGetCartOfWatch(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $store_id = $request->input('store_id');
        if($userAuth->is_dealer!=1) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '该用户不是经销商!', $validator->messages());
        $user_agent = AlbumAgentModel::where('user_id',$userAuth->id)->first();
        $count_user = AlbumWatchRecord::where([['agent_id',$user_agent->id],['store_id',$store_id]])->groupBy('open_id')->get();

        $users = Array();
        if($count_user){
            foreach($count_user as $key=>$val){
                $user = AlbumUserModel::where([['wechat_open_id',$val->open_id],['store_id',$val->store_id]])->select(['username','avatar','phone'])->first();
                $users[] = $user;
            }
        }
        $count = count($users);
        $action = Array();
        for($i=1;$i<=7;$i++){
            $res = AlbumWatchRecord::where([['agent_id',$user_agent->id],['store_id',$store_id],['action',$i]])->get();
            $action['type'.$i] = count($res);
        }
        return $this->api(compact('count','users','action'));
    }
    /**
     * @api {get} /api/album/checklogin 登陆应用(checklogin)
     * @apiDescription 登陆应用(checklogin)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *
     *     }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumchecklogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $favorite = AlbumManufacturerModel::where([['store_id',$data['store_id']]])->first();

        $conf = $favorite->redirectapp;
        return $this->api($conf);
    }

    /**
     * @api {get} /api/album/favorite_del 收藏删除(favorite_del)
     * @apiDescription 收藏删除(favorite_del)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [favorite_id]  收藏id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data":[]//返回状态
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumFavoriteDel(Request $request)
    {
        //$userAuth = AlbumXyxUserModel::find(1);
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'favorite_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
            'favorite_id.required'=>'缺少收藏参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $favorite = AlbumFavoriteModel::find($data['favorite_id']);
        if(!$favorite){
            $d = [
                'code' =>1,
                'msg' =>'删除失败，或者该收藏已移除',
            ];
        } else {
            $res = $favorite->delete();
            if($res){
                $d = [
                    'code' =>1,
                    'msg' =>'删除成功',
                ];
            } else {
                $d = [
                    'code' =>1,
                    'msg' =>'删除失败，或者该收藏已移除',
                ];
            }
        }
        return $this->api($d);
    }


    /**
     * @api {get} /api/album/save_form_id 添加Form_id(save_form_id)
     * @apiDescription 添加Form_id(save_form_id)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id
     * @apiParam {int}    [form_id]  form_id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//返回信息
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumSaveFormId(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'form_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
            'form_id.required'=>'缺少FormId',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $data['open_id'] = $userAuth->wechat_open_id;
        $res = AlbumFormId::create($data);
        if($res){
            $d = [
                'code' =>0,
                'msg' =>'success',
            ];
        }else{
            $d = [
                'code' =>1,
                'msg' =>'error',
            ];
        }
        return $this->api($d);
    }

    /**
     * @api {get} /api/album/add_favorite 添加收藏(add_favorite)
     * @apiDescription 添加收藏(favorite_list)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id
     * @apiParam {int}    [product_id]  商品id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//返回信息
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumAddFavorite(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'product_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
            'product_id.required'=>'缺少商品参数',
        ]);

        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $select_info = ['goods_id'=>$data['product_id']];
        if($userAuth->up_agent_id!=0){
            $add_record['agent_id'] = $userAuth->up_agent_id;
            $add_record['open_id'] = $userAuth->wechat_open_id;
            $add_record['action'] = 1;
            $add_record['store_id'] = $data['store_id'];
            $add_record['detail'] = json_encode($select_info);
            $user_agent = AlbumAgentModel::where('id',$userAuth->up_agent_id)->first();
            $agent = AlbumUserModel::where('id',$user_agent->user_id)->first();
            try{
                $this->sendLogsMessage($data['store_id'],$agent->wechat_open_id,1,$userAuth->username);
            }catch (\Exception $e){

            }
            AlbumWatchRecord::create($add_record);
        }
        $check_user = AlbumUserModel::find($userAuth->id);
        $check_f = AlbumFavoriteModel::where([['user_id',$userAuth->id],['product_id',$data['product_id']]])->first();
        if(!$check_user||$check_f){
            $d = [
                'code' =>1,
                'msg' =>'该用户不存在或者已添加',
            ];
            return $this->api($d);
        }
        $data['user_id'] = $userAuth->id;
        $res = AlbumFavoriteModel::create($data);
        if($res){
            $d = [
                'code' =>0,
                'msg' =>'success',
            ];
        }else{
            $d = [
                'code' =>1,
                'msg' =>'error',
            ];
        }
        return $this->api($d);
    }
    /**
     * @api {get} /api/album/cat 分类列表(cat)
     * @apiDescription 画册分类(cat)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [parent_id]  一级菜单传0 二级菜单的id从一级菜单里面获取
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *          {
     *              "id": 9,
     *              "name": "圣地亚哥",
     *              "parent_id": 0,
     *              "level": "00",
     *              "pic_url": "http://admin.xcx.com/upload/images/20180518/af6cc8fd71241744ccd638afc6ac25f2.png",
     *              "created_at": "2018-05-19 14:55:48",
     *              "updated_at": "2018-05-19 14:55:48",
     *              "store_id": 0,
     *              "deleted_at": null,
     *              "sort": 0
     *          }
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumCat(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $cat_id = 0;
        $store_id = request('store_id');
        $cats = AlbumCatModel::where([['parent_id',$cat_id],['store_id',$store_id]])->orderByDesc('sort')->get();
        return $this->api($cats);
    }

    /**
     * @api {get} /api/album/style 属性列表(style)
     * @apiDescription 分类样式(style)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *          {
     *              "id": 2,
     *              "name": "1111",
     *              "deleted_at": null,
     *              "created_at": "2018-06-05 17:35:08",
     *              "updated_at": "2018-06-05 17:35:08",
     *              "store_id": 0
     *          }
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumStyle(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $store_id = request('store_id');
        $style = AlbumProductStyleModel::where([['store_id',$store_id]])->orderByDesc('id')->get();
        return $this->api($style);
    }

    /**
     * @api {get} /api/album/set-price 经销商修改价格(set-price)
     * @apiDescription 画册(set-price)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [goods_id]  商品id
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [type]  修改类型 0 电话 1 价格
     * @apiParam {string}    [mobile]  电话号码
     * @apiParam {string}    [address]  地址
     * @apiParam {double}    [price]  价格
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data":[
     *          "msg":返回信息,
     *          "data":修改后价格
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumSetPrice(Request $request)
    {
        $userAuth = Auth('api')->user();
        $user_agent = AlbumAgentModel::where('user_id',$userAuth->id)->first();
        $agent_id = $user_agent['id'];
        $data = $request->all();
        //print_r($data);
        $save = array();
        $return_data = array();
        if($data['type'] == 0) {
            $save['mobile'] = $data['mobile'];
            $product = AlbumProductModel::where('store_id',$data['store_id'])->get();
            foreach($product as $key=>$val){
                $check = AlbumProductPriceModel::where([['agent_id',$agent_id],['store_id',$data['store_id']],['product_id',$val['id']]])->first();
                if(empty($check)){
                    $save['agent_id'] = $data['agent_id'];
                    $save['store_id'] = $data['store_id'];
                    $save['product_id'] = $val['id'];
                    $res = AlbumProductPriceModel::create($save);
                }else{
                    $res = AlbumProductPriceModel::where([['agent_id',$agent_id],['store_id',$data['store_id']],['product_id',$val['id']]])->update($save);
                }
                if(!$res){
                    $return['msg'] = 'error';
                    return $this->api($return);
                }
            }
            $update_agent['phone'] = $data['mobile'];
            $update_agent['address'] = $data['address'];

            $update_res = AlbumAgentModel::where('id',$agent_id)->update($update_agent);
            if(!$update_res){
                $return['msg'] = 'error';
                return $this->api($return);
            }
            $return_data['mobile'] = $data['mobile'];
            $return_data['address'] = $data['address'];
            $return['msg'] = 'success';
        } elseif ($data['type'] == 1){
            $save['price'] = $data['price'];
            $check = AlbumProductPriceModel::where([['agent_id',$agent_id],['store_id',$data['store_id']],['product_id',$data['goods_id']]])->first();
            if(empty($check)){
                $save['agent_id'] = $data['agent_id'];
                $save['store_id'] = $data['store_id'];
                $save['product_id'] = $data['goods_id'];
                $res = AlbumProductPriceModel::create($save);
            }else{
                $res = AlbumProductPriceModel::where([['agent_id',$agent_id],['store_id',$data['store_id']],['product_id',$data['goods_id']]])->update($save);
            }
            if($res){
                $return['msg'] = 'success';
                $return_data['price'] = $data['price'];
            } else {
                $return['msg'] = 'error';
            }
        }
        $return['data'] = $return_data;
        return $this->api($return);
    }

    /**
     * @api {post} /api/album/set-phone 获取用户号码(set-phone)
     * @apiDescription 获取用户号码(set-phone)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {string}    [code]  code
     * @apiParam {string}    [iv]  偏移量
     * @apiParam {string}    [encrypted]  加密参数
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data":[
     *          "msg":返回信息,
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumSavePhone(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'code' => 'required',
            'iv' => 'required',
            'encrypted' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
            'code.required'=>'缺少code参数',
            'iv.required'=>'缺少偏移量参数',
            'encrypted.required'=>'缺少加密参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $this->wechat_app = AlbumManufacturerModel::where('store_id',$request->input('store_id'))->first();
        $config = [
            'app_id' => $this->wechat_app->xyx_id,
            'secret' => $this->wechat_app->xyx_secret,

            // 下面为可选项
            // 指定 API 调用返回结果的类型：array(default)/collection/object/raw/自定义类名
            'response_type' => 'array',


        ];

        $app = Factory::miniProgram($config);
        $res = $app->auth->session($request->input('code'));

        if (!$res || empty($res['openid'])) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '获取用户OpenId失败!', $validator->messages());
        }

        $session_key = $res['session_key'];
        $pc = new WXBizDataCrypt($this->wechat_app->xyx_id, $session_key);
        $errCode = $pc->decryptData($request->input('encrypted'), $request->input('iv'), $data);
        if($errCode==0){
            $data = json_decode($data,true);
            $userAuth->phone = $data['phoneNumber'];

            $res = $userAuth->save();
            if($res){
                return $this->api(['msg'=>'success']);
            }else{
                return $this->api(['msg'=>'error']);
            }
        }elseif($errCode == -41003){
            return $this->api(['msg'=>'请求错误，请重试']);
        }

    }

    /**
     * @api {post} /api/album/set-watch 获取用户操作记录(set-watch)
     * @apiDescription 获取用户操作记录(set-watch)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {string}    [detail] 详细
     * @apiParam {string}    [type]   5点击图片 6 点击导航 7一键拨号
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data":[
     *          "msg":返回信息,
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumSetWatch(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'type' => 'required',
            'detail' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
            'type.required'=>'缺少类型参数',
            'detail.required'=>'缺少详细参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        if($data['type']==5&&!empty($data['goods_id'])) {
            $select_info = ['goods_id'=>$data['goods_id'],'detail'=>$data['detail']];
        }elseif($data['type']==5&&empty($data['goods_id'])){
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '缺少goodsid');
        }else{
            $select_info = ['detail'=>$data['detail']];
        }
        if($userAuth->up_agent_id!=0){
            $add_record['agent_id'] = $userAuth->up_agent_id;
            $add_record['open_id'] = $userAuth->wechat_open_id;
            $add_record['action'] = $data['type'];
            $add_record['store_id'] = 1;
            $add_record['detail'] = json_encode($select_info);
           // dd($add_record);
            $res = AlbumWatchRecord::create($add_record);
            $user_agent = AlbumAgentModel::where('id',$userAuth->up_agent_id)->first();
            $agent = AlbumUserModel::where('id',$user_agent->user_id)->first();
            if($res){
                try{
                    $this->sendLogsMessage($data['store_id'],$agent->wechat_open_id,$data['type'],$userAuth->username);
                }catch (\Exception $e){

                }
                return $this->api(['msg'=>'success']);
            }else{
                return $this->api(['msg'=>'error']);
            }
        }
    }

    /**
     * @param $storeid
     * @param $open_id
     * @param $action 1 收藏  2查看类目 3查看商品 4登陆 5点击图片 6 点击导航 7一键拨号
     * @throws \EasyWeChat\Kernel\Exceptions\InvalidArgumentException
     */
    private function sendLogsMessage($storeid,$open_id,$action,$name)
    {
        $user = AlbumUserModel::where('wechat_open_id',$open_id)->first();
        $formId = AlbumFormId::where([['open_id',$open_id]])->first();
        if($user&&$formId){
            $content = '';
            switch ($action){
                case 1:
                    $content = '有用户收藏了您的产品';
                    break;
                case 2;
                    $content = '有用户查看了您的产品列表';
                    break;
                case 3;
                    $content = '有用户查看了您的商品';
                    break;
                case 4;
                    $content = '有用户进入了您的画册';
                    break;
                case 5;
                    $content = '有用户点击了您的某款产品详情';
                    break;
                case 6;
                    $content = '有用户点击了导航到您的位置';
                    break;
                case 7;
                    $content = '有用户点击了您的号码';
                    break;
            }
            $this->wechat_app = AlbumManufacturerModel::where('store_id',$storeid)->first();
            $config = [
                'app_id' => $this->wechat_app->app_id,
                'secret' => $this->wechat_app->app_secret,

                // 下面为可选项
                // 指定 API 调用返回结果的类型：array(default)/collection/object/raw/自定义类名
                'response_type' => 'array',
            ];
            $app = Factory::miniProgram($config);
            $res = $app->template_message->send([
                'touser' => $open_id,
                'template_id' => '9PDTfnhsRvdNwpPMIcYLL7wQF4SZkB8-9ZhXUfthbmw',
                'page' => 'pages/logs/logs',
                'form_id' => $formId->form_id,
                'data' => [
                    'keyword1' => $name,
                    'keyword2' => $content,
                    'keyword3' => date('Y-m-d H:i'),
                ],
            ]);
          //  dd($res);
            if($res){
                $formId->delete();
            }
        }

    }

    /**
     * @api {get} /api/album/add_agent 申请经销商(add_agent)
     * @apiDescription 申请经销商(add_agent)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id
     * @apiParam {int}    [realname]  姓名
     * @apiParam {int}    [address]  地址
     * @apiParam {int}    [phone]  电话
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//返回信息
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumAddAgent(Request $request)
    {
        $userAuth = Auth('api')->user();
        if(!$userAuth) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        $validator = Validator::make($request->all(), [
            'realname' => 'required',
            'address' => 'required',
            'phone' => 'required',
            'store_id' => 'required',
        ],[
            'address.required'=>'缺少地址参数',
            'real_name.required'=>'缺少信息参数',
            'phone.required'=>'缺少电话参数',
            'store_id.required'=>'缺少商户参数',
        ]);

        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $agent_check = AlbumAgentModel::where([['store_id',$data['store_id']],['user_id',$userAuth->id]])->first();
        if($agent_check){
            if($agent_check->status==0) return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '该用户已提交申请！');
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '该用户已是经销商！');
        }
        $data['status'] = 0;
        $data['user_id'] = $userAuth->id;
        $data['name'] = $userAuth->username;
        $res = AlbumAgentModel::create($data);
        if($res){
            $d = [
                'code' =>0,
                'msg' =>'success',
            ];
        }else{
            $d = [
                'code' =>1,
                'msg' =>'error',
            ];
        }
        return $this->api($d);
    }
}
